==> zio-aws-cloud9_2.13-5.17.115.1-sources.jar: zio/aws/cloud9/model/ListTagsForResourceResponse.scala <==
package zio.aws.cloud9.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceResponse(
    tags: Option[Iterable[zio.aws.cloud9.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.cloud9.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.cloud9.model.ListTagsForResourceResponse.wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloud9.model.ListTagsForResourceResponse =
      zio.aws.cloud9.model.ListTagsForResourceResponse(
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def tags: Option[List[zio.aws.cloud9.model.Tag.ReadOnly]]
    def getTags: ZIO[Any, AwsError, List[zio.aws.cloud9.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse
  ) extends zio.aws.cloud9.model.ListTagsForResourceResponse.ReadOnly {
    override val tags: Option[List[zio.aws.cloud9.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cloud9.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse
  ): zio.aws.cloud9.model.ListTagsForResourceResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-cloud9_2.13-5.17.233.1-sources.jar: zio/aws/cloud9/model/ListTagsForResourceResponse.scala <==
package zio.aws.cloud9.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceResponse(
    tags: Optional[Iterable[zio.aws.cloud9.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.cloud9.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.cloud9.model.ListTagsForResourceResponse.wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloud9.model.ListTagsForResourceResponse =
      zio.aws.cloud9.model.ListTagsForResourceResponse(
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def tags: Optional[List[zio.aws.cloud9.model.Tag.ReadOnly]]
    def getTags: ZIO[Any, AwsError, List[zio.aws.cloud9.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse
  ) extends zio.aws.cloud9.model.ListTagsForResourceResponse.ReadOnly {
    override val tags: Optional[List[zio.aws.cloud9.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloud9.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloud9.model.ListTagsForResourceResponse
  ): zio.aws.cloud9.model.ListTagsForResourceResponse.ReadOnly = new Wrapper(
    impl
  )
}
